mypsl
========

**Maintainer:** k dot shenk at gmail dot com

The aim of **mypsl** is to provide a simple interface for querying and filtering the MySQL process list. Over time
the available options have become bloated, so some cases may not be *so simple*.

Installation
------------

**Via PIP:**
``pip install mypsl``

Usage
-----

    ::

        mypsl --options


stuff

Contributing
------------
Suggestions and contributions are welcome. Please fork me and create PRs back to the ``develop`` branch.

